unit UMainForm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, DB, ADODB, ComCtrls, msDBTreeView, StdCtrls, DBCtrls, Menus,
  ExtCtrls, ImgList, Buttons, ActnList;

type
  TMainForm = class(TForm)
    ADODataSet: TADODataSet;
    msDBTreeView: TmsDBTreeView;
    DBRichEdit: TDBRichEdit;
    DataSource: TDataSource;
    ActionList: TActionList;
    Action_FileOpen: TAction;
    Action_FileClose: TAction;
    Action_FileExit: TAction;
    Action_LanguageEnglish: TAction;
    Action_LanguageRussian: TAction;
    Action_EditAddFile: TAction;
    Action_EditAddFolder: TAction;
    Action_EditDelNode: TAction;
    ImgList_TreeView: TImageList;
    MainMenu: TMainMenu;
    MMenu_File: TMenuItem;
    Open1: TMenuItem;
    Close1: TMenuItem;
    N1: TMenuItem;
    Exit1: TMenuItem;
    MMenu_Edit: TMenuItem;
    Addrecord1: TMenuItem;
    AddFolder1: TMenuItem;
    DeleteNode1: TMenuItem;
    MMenu_Language: TMenuItem;
    English1: TMenuItem;
    Russian1: TMenuItem;
    Panel_Top: TPanel;
    SpeedButton1: TSpeedButton;
    SpeedButton2: TSpeedButton;
    SpeedButton3: TSpeedButton;
    SpeedButton4: TSpeedButton;
    SpeedButton5: TSpeedButton;
    StatusBar: TStatusBar;
    ImgList_MainMenu: TImageList;
    procedure FormCreate(Sender: TObject);
    procedure msDBTreeViewBeforeAddNode(Sender: TObject; _type: Integer;
      var Confirm: Boolean);
    procedure msDBTreeViewBeforeDelNode(Sender: TObject; _type: Integer;
      var Confirm: Boolean);
    procedure Action_FileOpenExecute(Sender: TObject);
    procedure Action_FileCloseExecute(Sender: TObject);
    procedure Action_FileExitExecute(Sender: TObject);
    procedure Action_EditAddFileExecute(Sender: TObject);
    procedure Action_EditAddFolderExecute(Sender: TObject);
    procedure Action_EditDelNodeExecute(Sender: TObject);
    procedure Action_LanguageEnglishExecute(Sender: TObject);
    procedure Action_LanguageRussianExecute(Sender: TObject);
    procedure msDBTreeViewSelectNode(Sender: TObject; Node: TTreeNode);
  private
    ID_Lang : integer;
    procedure Open_Connection(const Value : integer);
    procedure SwitchLanguage(const ID : integer);
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.dfm}

const
  RES_STR_MSG : array [1..6, 1..2] of string[50] =
  (
    ('Add Folder?',    ' ?'),
    ('Add File?',      ' ?'),
    ('Delete Folder?', ' ?'),
    ('Delete File?',   ' ?'),
    ('Selected - Folder', ' - '),
    ('Selected - File',   ' - ')
  );

//---------------------------------------------------------------------------
procedure TMainForm.Open_Connection(const Value : integer);
const
  ConnStr      = 'Provider=%s;Data Provider=%s;Data Source=%s';
  Provider     = 'MSDataShape.1';
  DataProvider = 'Microsoft.Jet.OLEDB.4.0';
var
  DataSource : string;
begin
  ID_Lang := Value;

  if (ADODataSet.Active) then begin
    msDBTreeView.Close();
    ADODataSet.Close();
  end;

  DataSource := ExtractFilePath(Application.ExeName) + 'DB.mdb';
  ADODataSet.ConnectionString := Format(ConnStr, [Provider, DataProvider, DataSource]);
  if (ID_Lang = 1) then
    ADODataSet.CommandText := 'English'
  else
    ADODataSet.CommandText := 'Russian';

  ADODataSet.Open();
  msDBTreeView.Open();
end;

//---------------------------------------------------------------------------
procedure TMainForm.SwitchLanguage(const ID : integer);
begin
  if (ID = 1) then begin
    MMenu_File.Caption             := 'File';
    Action_FileOpen.Caption        := 'Open';
    Action_FileClose.Caption       := 'Close';
    Action_FileExit.Caption        := 'Exit';
    MMenu_Edit.Caption             := 'Edit';
    Action_EditAddFile.Caption     := 'Add File';
    Action_EditAddFolder.Caption   := 'Add Folder';
    Action_EditDelNode.Caption     := 'Delete Node';
    MMenu_Language.Caption         := 'Language';
    Action_LanguageEnglish.Caption := 'English';
    Action_LanguageRussian.Caption := 'Russian';
  end
  else begin
    MMenu_File.Caption             := '';
    Action_FileOpen.Caption        := '';
    Action_FileClose.Caption       := '';
    Action_FileExit.Caption        := '';
    MMenu_Edit.Caption             := '';
    Action_EditAddFile.Caption     := ' ';
    Action_EditAddFolder.Caption   := ' ';
    Action_EditDelNode.Caption     := ' ';
    MMenu_Language.Caption         := '';
    Action_LanguageEnglish.Caption := '';
    Action_LanguageRussian.Caption := '';
  end;
end;

//---------------------------------------------------------------------------
procedure TMainForm.FormCreate(Sender: TObject);
begin
  Open_Connection(1);
end;

//---------------------------------------------------------------------------
procedure TMainForm.msDBTreeViewBeforeAddNode(Sender: TObject;
  _type: Integer; var Confirm: Boolean);
var
  msg : string;
begin
  msg := RES_STR_MSG[_type + 1, ID_Lang];
  Confirm := (MessageDlg(msg, mtConfirmation, [mbYes, mbNo], 0) = mrYes);
end;

//---------------------------------------------------------------------------
procedure TMainForm.msDBTreeViewBeforeDelNode(Sender: TObject;
  _type: Integer; var Confirm: Boolean);
var
  msg : string;
begin
  msg := RES_STR_MSG[_type + 3, ID_Lang];
  Confirm := (MessageDlg(msg, mtConfirmation, [mbYes, mbNo], 0) = mrYes);
end;
//---------------------------------------------------------------------------
procedure TMainForm.msDBTreeViewSelectNode(Sender: TObject;
  Node: TTreeNode);
begin
  case (msDBTreeView.TypeOfSelected) of
    FOLDER_TypeOfNode :
    begin
      DBRichEdit.Color := clSilver;
      StatusBar.Panels.Items[0].Text := RES_STR_MSG[5, ID_Lang];
    end;
    RECORD_TypeOfNode :
    begin
      DBRichEdit.Color := clWhite;
      StatusBar.Panels.Items[0].Text := RES_STR_MSG[6, ID_Lang];
    end;
  end;
end;

//---------------------------------------------------------------------------
procedure TMainForm.Action_FileOpenExecute(Sender: TObject);
begin
  msDBTreeView.Open();
end;

//---------------------------------------------------------------------------
procedure TMainForm.Action_FileCloseExecute(Sender: TObject);
begin
  msDBTreeView.Close();
end;

//---------------------------------------------------------------------------
procedure TMainForm.Action_FileExitExecute(Sender: TObject);
begin
  Close();
end;

//---------------------------------------------------------------------------
procedure TMainForm.Action_EditAddFileExecute(Sender: TObject);
begin
  msDBTreeView.AddNode(RECORD_TypeOfNode);
end;

//---------------------------------------------------------------------------
procedure TMainForm.Action_EditAddFolderExecute(Sender: TObject);
begin
  msDBTreeView.AddNode(FOLDER_TypeOfNode);
end;

//---------------------------------------------------------------------------
procedure TMainForm.Action_EditDelNodeExecute(Sender: TObject);
begin
  msDBTreeView.DelNode();
end;

//---------------------------------------------------------------------------
procedure TMainForm.Action_LanguageEnglishExecute(Sender: TObject);
begin
  SwitchLanguage(1);
  Open_Connection(1);
end;

//---------------------------------------------------------------------------
procedure TMainForm.Action_LanguageRussianExecute(Sender: TObject);
begin
  SwitchLanguage(2);
  Open_Connection(2);
end;

end.

